#!/usr/bin/env python
import xml.etree.ElementTree as ET


class ietf_netconf(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def get_config_input_source_config_source_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_config = ET.Element("get_config")
        config = get_config
        input = ET.SubElement(get_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        candidate = ET.SubElement(config_source, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_config_input_source_config_source_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_config = ET.Element("get_config")
        config = get_config
        input = ET.SubElement(get_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        running = ET.SubElement(config_source, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_config_input_source_config_source_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_config = ET.Element("get_config")
        config = get_config
        input = ET.SubElement(get_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        startup = ET.SubElement(config_source, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_config_input_with_defaults(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_config = ET.Element("get_config")
        config = get_config
        input = ET.SubElement(get_config, "input")
        with_defaults = ET.SubElement(input, "with-defaults", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults")
        with_defaults.text = kwargs.pop('with_defaults')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_config_input_with_inactive(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_config = ET.Element("get_config")
        config = get_config
        input = ET.SubElement(get_config, "input")
        with_inactive = ET.SubElement(input, "with-inactive", xmlns="http://tail-f.com/ns/netconf/inactive/1.0")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_target_config_target_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        candidate = ET.SubElement(config_target, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_target_config_target_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        running = ET.SubElement(config_target, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_default_operation(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        default_operation = ET.SubElement(input, "default-operation")
        default_operation.text = kwargs.pop('default_operation')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_test_option(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        test_option = ET.SubElement(input, "test-option")
        test_option.text = kwargs.pop('test_option')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_error_option(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        error_option = ET.SubElement(input, "error-option")
        error_option.text = kwargs.pop('error_option')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_edit_content_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        edit_content = ET.SubElement(input, "edit-content")
        url = ET.SubElement(edit_content, "url")
        url = ET.SubElement(url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_with_inactive(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        with_inactive = ET.SubElement(input, "with-inactive", xmlns="http://tail-f.com/ns/netconf/inactive/1.0")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_target_config_target_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        candidate = ET.SubElement(config_target, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_target_config_target_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        running = ET.SubElement(config_target, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_target_config_target_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        startup = ET.SubElement(config_target, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_target_config_target_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        url = ET.SubElement(config_target, "url")
        url = ET.SubElement(url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_source_config_source_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        candidate = ET.SubElement(config_source, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_source_config_source_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        running = ET.SubElement(config_source, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_source_config_source_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        startup = ET.SubElement(config_source, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_source_config_source_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        url = ET.SubElement(config_source, "url")
        url = ET.SubElement(url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_with_defaults(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        with_defaults = ET.SubElement(input, "with-defaults", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults")
        with_defaults.text = kwargs.pop('with_defaults')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_with_inactive(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        with_inactive = ET.SubElement(input, "with-inactive", xmlns="http://tail-f.com/ns/netconf/inactive/1.0")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def delete_config_input_target_config_target_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        delete_config = ET.Element("delete_config")
        config = delete_config
        input = ET.SubElement(delete_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        startup = ET.SubElement(config_target, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def delete_config_input_target_config_target_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        delete_config = ET.Element("delete_config")
        config = delete_config
        input = ET.SubElement(delete_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        url = ET.SubElement(config_target, "url")
        url = ET.SubElement(url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def lock_input_target_config_target_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        lock = ET.Element("lock")
        config = lock
        input = ET.SubElement(lock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        candidate = ET.SubElement(config_target, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def lock_input_target_config_target_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        lock = ET.Element("lock")
        config = lock
        input = ET.SubElement(lock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        running = ET.SubElement(config_target, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def lock_input_target_config_target_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        lock = ET.Element("lock")
        config = lock
        input = ET.SubElement(lock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        startup = ET.SubElement(config_target, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def unlock_input_target_config_target_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        unlock = ET.Element("unlock")
        config = unlock
        input = ET.SubElement(unlock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        candidate = ET.SubElement(config_target, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def unlock_input_target_config_target_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        unlock = ET.Element("unlock")
        config = unlock
        input = ET.SubElement(unlock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        running = ET.SubElement(config_target, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def unlock_input_target_config_target_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        unlock = ET.Element("unlock")
        config = unlock
        input = ET.SubElement(unlock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        startup = ET.SubElement(config_target, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_input_with_defaults(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get = ET.Element("get")
        config = get
        input = ET.SubElement(get, "input")
        with_defaults = ET.SubElement(input, "with-defaults", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults")
        with_defaults.text = kwargs.pop('with_defaults')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_input_with_inactive(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get = ET.Element("get")
        config = get
        input = ET.SubElement(get, "input")
        with_inactive = ET.SubElement(input, "with-inactive", xmlns="http://tail-f.com/ns/netconf/inactive/1.0")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def kill_session_input_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        kill_session = ET.Element("kill_session")
        config = kill_session
        input = ET.SubElement(kill_session, "input")
        session_id = ET.SubElement(input, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def commit_input_confirmed(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        commit = ET.Element("commit")
        config = commit
        input = ET.SubElement(commit, "input")
        confirmed = ET.SubElement(input, "confirmed")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def commit_input_confirm_timeout(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        commit = ET.Element("commit")
        config = commit
        input = ET.SubElement(commit, "input")
        confirm_timeout = ET.SubElement(input, "confirm-timeout")
        confirm_timeout.text = kwargs.pop('confirm_timeout')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def commit_input_persist(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        commit = ET.Element("commit")
        config = commit
        input = ET.SubElement(commit, "input")
        persist = ET.SubElement(input, "persist")
        persist.text = kwargs.pop('persist')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def commit_input_persist_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        commit = ET.Element("commit")
        config = commit
        input = ET.SubElement(commit, "input")
        persist_id = ET.SubElement(input, "persist-id")
        persist_id.text = kwargs.pop('persist_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cancel_commit_input_persist_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cancel_commit = ET.Element("cancel_commit")
        config = cancel_commit
        input = ET.SubElement(cancel_commit, "input")
        persist_id = ET.SubElement(input, "persist-id")
        persist_id.text = kwargs.pop('persist_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def validate_input_source_config_source_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        validate = ET.Element("validate")
        config = validate
        input = ET.SubElement(validate, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        candidate = ET.SubElement(config_source, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def validate_input_source_config_source_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        validate = ET.Element("validate")
        config = validate
        input = ET.SubElement(validate, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        running = ET.SubElement(config_source, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def validate_input_source_config_source_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        validate = ET.Element("validate")
        config = validate
        input = ET.SubElement(validate, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        startup = ET.SubElement(config_source, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def validate_input_source_config_source_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        validate = ET.Element("validate")
        config = validate
        input = ET.SubElement(validate, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        url = ET.SubElement(config_source, "url")
        url = ET.SubElement(url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_config_input_source_config_source_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_config = ET.Element("get_config")
        config = get_config
        input = ET.SubElement(get_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        candidate = ET.SubElement(config_source, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_config_input_source_config_source_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_config = ET.Element("get_config")
        config = get_config
        input = ET.SubElement(get_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        running = ET.SubElement(config_source, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_config_input_source_config_source_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_config = ET.Element("get_config")
        config = get_config
        input = ET.SubElement(get_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        startup = ET.SubElement(config_source, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_config_input_with_defaults(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_config = ET.Element("get_config")
        config = get_config
        input = ET.SubElement(get_config, "input")
        with_defaults = ET.SubElement(input, "with-defaults", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults")
        with_defaults.text = kwargs.pop('with_defaults')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_config_input_with_inactive(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_config = ET.Element("get_config")
        config = get_config
        input = ET.SubElement(get_config, "input")
        with_inactive = ET.SubElement(input, "with-inactive", xmlns="http://tail-f.com/ns/netconf/inactive/1.0")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_target_config_target_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        candidate = ET.SubElement(config_target, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_target_config_target_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        running = ET.SubElement(config_target, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_default_operation(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        default_operation = ET.SubElement(input, "default-operation")
        default_operation.text = kwargs.pop('default_operation')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_test_option(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        test_option = ET.SubElement(input, "test-option")
        test_option.text = kwargs.pop('test_option')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_error_option(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        error_option = ET.SubElement(input, "error-option")
        error_option.text = kwargs.pop('error_option')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_edit_content_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        edit_content = ET.SubElement(input, "edit-content")
        url = ET.SubElement(edit_content, "url")
        url = ET.SubElement(url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def edit_config_input_with_inactive(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        edit_config = ET.Element("edit_config")
        config = edit_config
        input = ET.SubElement(edit_config, "input")
        with_inactive = ET.SubElement(input, "with-inactive", xmlns="http://tail-f.com/ns/netconf/inactive/1.0")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_target_config_target_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        candidate = ET.SubElement(config_target, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_target_config_target_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        running = ET.SubElement(config_target, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_target_config_target_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        startup = ET.SubElement(config_target, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_target_config_target_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        url = ET.SubElement(config_target, "url")
        url = ET.SubElement(url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_source_config_source_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        candidate = ET.SubElement(config_source, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_source_config_source_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        running = ET.SubElement(config_source, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_source_config_source_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        startup = ET.SubElement(config_source, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_source_config_source_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        url = ET.SubElement(config_source, "url")
        url = ET.SubElement(url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_with_defaults(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        with_defaults = ET.SubElement(input, "with-defaults", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults")
        with_defaults.text = kwargs.pop('with_defaults')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def copy_config_input_with_inactive(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        copy_config = ET.Element("copy_config")
        config = copy_config
        input = ET.SubElement(copy_config, "input")
        with_inactive = ET.SubElement(input, "with-inactive", xmlns="http://tail-f.com/ns/netconf/inactive/1.0")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def delete_config_input_target_config_target_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        delete_config = ET.Element("delete_config")
        config = delete_config
        input = ET.SubElement(delete_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        startup = ET.SubElement(config_target, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def delete_config_input_target_config_target_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        delete_config = ET.Element("delete_config")
        config = delete_config
        input = ET.SubElement(delete_config, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        url = ET.SubElement(config_target, "url")
        url = ET.SubElement(url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def lock_input_target_config_target_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        lock = ET.Element("lock")
        config = lock
        input = ET.SubElement(lock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        candidate = ET.SubElement(config_target, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def lock_input_target_config_target_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        lock = ET.Element("lock")
        config = lock
        input = ET.SubElement(lock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        running = ET.SubElement(config_target, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def lock_input_target_config_target_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        lock = ET.Element("lock")
        config = lock
        input = ET.SubElement(lock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        startup = ET.SubElement(config_target, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def unlock_input_target_config_target_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        unlock = ET.Element("unlock")
        config = unlock
        input = ET.SubElement(unlock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        candidate = ET.SubElement(config_target, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def unlock_input_target_config_target_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        unlock = ET.Element("unlock")
        config = unlock
        input = ET.SubElement(unlock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        running = ET.SubElement(config_target, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def unlock_input_target_config_target_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        unlock = ET.Element("unlock")
        config = unlock
        input = ET.SubElement(unlock, "input")
        target = ET.SubElement(input, "target")
        config_target = ET.SubElement(target, "config-target")
        startup = ET.SubElement(config_target, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_input_with_defaults(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get = ET.Element("get")
        config = get
        input = ET.SubElement(get, "input")
        with_defaults = ET.SubElement(input, "with-defaults", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults")
        with_defaults.text = kwargs.pop('with_defaults')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_input_with_inactive(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get = ET.Element("get")
        config = get
        input = ET.SubElement(get, "input")
        with_inactive = ET.SubElement(input, "with-inactive", xmlns="http://tail-f.com/ns/netconf/inactive/1.0")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def kill_session_input_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        kill_session = ET.Element("kill_session")
        config = kill_session
        input = ET.SubElement(kill_session, "input")
        session_id = ET.SubElement(input, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def commit_input_confirmed(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        commit = ET.Element("commit")
        config = commit
        input = ET.SubElement(commit, "input")
        confirmed = ET.SubElement(input, "confirmed")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def commit_input_confirm_timeout(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        commit = ET.Element("commit")
        config = commit
        input = ET.SubElement(commit, "input")
        confirm_timeout = ET.SubElement(input, "confirm-timeout")
        confirm_timeout.text = kwargs.pop('confirm_timeout')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def commit_input_persist(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        commit = ET.Element("commit")
        config = commit
        input = ET.SubElement(commit, "input")
        persist = ET.SubElement(input, "persist")
        persist.text = kwargs.pop('persist')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def commit_input_persist_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        commit = ET.Element("commit")
        config = commit
        input = ET.SubElement(commit, "input")
        persist_id = ET.SubElement(input, "persist-id")
        persist_id.text = kwargs.pop('persist_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cancel_commit_input_persist_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cancel_commit = ET.Element("cancel_commit")
        config = cancel_commit
        input = ET.SubElement(cancel_commit, "input")
        persist_id = ET.SubElement(input, "persist-id")
        persist_id.text = kwargs.pop('persist_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def validate_input_source_config_source_candidate_candidate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        validate = ET.Element("validate")
        config = validate
        input = ET.SubElement(validate, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        candidate = ET.SubElement(config_source, "candidate")
        candidate = ET.SubElement(candidate, "candidate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def validate_input_source_config_source_running_running(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        validate = ET.Element("validate")
        config = validate
        input = ET.SubElement(validate, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        running = ET.SubElement(config_source, "running")
        running = ET.SubElement(running, "running")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def validate_input_source_config_source_startup_startup(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        validate = ET.Element("validate")
        config = validate
        input = ET.SubElement(validate, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        startup = ET.SubElement(config_source, "startup")
        startup = ET.SubElement(startup, "startup")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def validate_input_source_config_source_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        validate = ET.Element("validate")
        config = validate
        input = ET.SubElement(validate, "input")
        source = ET.SubElement(input, "source")
        config_source = ET.SubElement(source, "config-source")
        url = ET.SubElement(config_source, "url")
        url = ET.SubElement(url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_chassis(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def hide_virtual_ip_holder_chassis_virtual_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_virtual_ip_holder = ET.SubElement(config, "hide-virtual-ip-holder", xmlns="urn:brocade.com:mgmt:brocade-chassis")
        chassis = ET.SubElement(hide_virtual_ip_holder, "chassis")
        virtual_ip = ET.SubElement(chassis, "virtual-ip")
        virtual_ip.text = kwargs.pop('virtual_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_virtual_ip_holder_chassis_virtual_ipv6(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_virtual_ip_holder = ET.SubElement(config, "hide-virtual-ip-holder", xmlns="urn:brocade.com:mgmt:brocade-chassis")
        chassis = ET.SubElement(hide_virtual_ip_holder, "chassis")
        virtual_ipv6 = ET.SubElement(chassis, "virtual-ipv6")
        virtual_ipv6.text = kwargs.pop('virtual_ipv6')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_virtual_ip_holder_chassis_oper_address_virtual_oper_Vip_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_virtual_ip_holder = ET.SubElement(config, "hide-virtual-ip-holder", xmlns="urn:brocade.com:mgmt:brocade-chassis")
        chassis = ET.SubElement(hide_virtual_ip_holder, "chassis")
        oper_address = ET.SubElement(chassis, "oper-address")
        virtual_oper_Vip_address = ET.SubElement(oper_address, "virtual-oper-Vip-address")
        virtual_oper_Vip_address.text = kwargs.pop('virtual_oper_Vip_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_virtual_ip_holder_chassis_virtual_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_virtual_ip_holder = ET.SubElement(config, "hide-virtual-ip-holder", xmlns="urn:brocade.com:mgmt:brocade-chassis")
        chassis = ET.SubElement(hide_virtual_ip_holder, "chassis")
        virtual_ip = ET.SubElement(chassis, "virtual-ip")
        virtual_ip.text = kwargs.pop('virtual_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_virtual_ip_holder_chassis_virtual_ipv6(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_virtual_ip_holder = ET.SubElement(config, "hide-virtual-ip-holder", xmlns="urn:brocade.com:mgmt:brocade-chassis")
        chassis = ET.SubElement(hide_virtual_ip_holder, "chassis")
        virtual_ipv6 = ET.SubElement(chassis, "virtual-ipv6")
        virtual_ipv6.text = kwargs.pop('virtual_ipv6')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_virtual_ip_holder_chassis_oper_address_virtual_oper_Vip_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_virtual_ip_holder = ET.SubElement(config, "hide-virtual-ip-holder", xmlns="urn:brocade.com:mgmt:brocade-chassis")
        chassis = ET.SubElement(hide_virtual_ip_holder, "chassis")
        oper_address = ET.SubElement(chassis, "oper-address")
        virtual_oper_Vip_address = ET.SubElement(oper_address, "virtual-oper-Vip-address")
        virtual_oper_Vip_address.text = kwargs.pop('virtual_oper_Vip_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""


import unittest
import xml.etree.ElementTree as ET
import pynos.versions.base.snmp
import pynos.utilities


class TestSNMP(unittest.TestCase):
    """
    System unit tests. Compare expected XML to generated XML.
    """
    def setUp(self):
        self.snmp = pynos.versions.base.snmp.SNMP(pynos.utilities.return_xml)
        self.namespace = 'urn:brocade.com:mgmt:brocade-snmp'
        self.community = 'public'

    def test_add_snmp_community(self):
        expected = '<config><snmp-server xmlns="{0}"><community><community>'\
                   '{1}</community></community></snmp-server>'\
                   '</config>'.format(self.namespace, self.community)
        result = self.snmp.add_snmp_community(community='public')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_add_snmp_community_exception(self):
        with self.assertRaises(KeyError):
            self.snmp.add_snmp_community()

    def test_del_snmp_community(self):
        expected = '<config><snmp-server xmlns="{0}">'\
                   '<community operation="delete"><community>{1}</community>'\
                   '</community></snmp-server></config>'.format(self.namespace,
                                                                self.community)
        result = self.snmp.del_snmp_community(community='public')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_del_snmp_community_exception(self):
        with self.assertRaises(KeyError):
            self.snmp.del_snmp_community()

    def test_add_snmp_host(self):
        expected = '<config><snmp-server xmlns="{0}"><host><ip>10.10.10.10'\
                   '</ip><community>{1}</community><udp-port>162</udp-port>'\
                   '</host></snmp-server></config>'.format(self.namespace,
                                                           self.community)
        result = self.snmp.add_snmp_host(community='public',
                                         host_info=('10.10.10.10', '162'))
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_add_snmp_host_exception(self):
        with self.assertRaises(KeyError):
            self.snmp.add_snmp_host()

    def test_del_snmp_host(self):
        expected = '<config><snmp-server xmlns="{0}">'\
                   '<host operation="delete"><ip>10.10.10.10</ip><community>'\
                   '{1}</community><udp-port>162</udp-port></host>'\
                   '</snmp-server></config>'.format(self.namespace,
                                                    self.community)
        result = self.snmp.del_snmp_host(community='public',
                                         host_info=('10.10.10.10', '162'))
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_del_snmp_host_exception(self):
        with self.assertRaises(KeyError):
            self.snmp.del_snmp_host()



#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_port_profile_ext(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def get_port_profile_for_intf_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        input = ET.SubElement(get_port_profile_for_intf, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_input_request_type_get_request_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        input = ET.SubElement(get_port_profile_for_intf, "input")
        request_type = ET.SubElement(input, "request-type")
        get_request = ET.SubElement(request_type, "get-request")
        interface_type = ET.SubElement(get_request, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_input_request_type_get_request_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        input = ET.SubElement(get_port_profile_for_intf, "input")
        request_type = ET.SubElement(input, "request-type")
        get_request = ET.SubElement(request_type, "get-request")
        interface_name = ET.SubElement(get_request, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_input_request_type_getnext_request_last_received_interface_info_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        input = ET.SubElement(get_port_profile_for_intf, "input")
        request_type = ET.SubElement(input, "request-type")
        getnext_request = ET.SubElement(request_type, "getnext-request")
        last_received_interface_info = ET.SubElement(getnext_request, "last-received-interface-info")
        interface_type = ET.SubElement(last_received_interface_info, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_input_request_type_getnext_request_last_received_interface_info_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        input = ET.SubElement(get_port_profile_for_intf, "input")
        request_type = ET.SubElement(input, "request-type")
        getnext_request = ET.SubElement(request_type, "getnext-request")
        last_received_interface_info = ET.SubElement(getnext_request, "last-received-interface-info")
        interface_name = ET.SubElement(last_received_interface_info, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_output_interface_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        output = ET.SubElement(get_port_profile_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_type = ET.SubElement(interface, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_output_interface_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        output = ET.SubElement(get_port_profile_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_name = ET.SubElement(interface, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_output_interface_port_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        output = ET.SubElement(get_port_profile_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        port_profile = ET.SubElement(interface, "port-profile")
        name = ET.SubElement(port_profile, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_output_has_more(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        output = ET.SubElement(get_port_profile_for_intf, "output")
        has_more = ET.SubElement(output, "has-more")
        has_more.text = kwargs.pop('has_more')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        input = ET.SubElement(get_port_profile_status, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_input_port_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        input = ET.SubElement(get_port_profile_status, "input")
        port_profile_name = ET.SubElement(input, "port-profile-name")
        port_profile_name.text = kwargs.pop('port_profile_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_input_port_profile_status(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        input = ET.SubElement(get_port_profile_status, "input")
        port_profile_status = ET.SubElement(input, "port-profile-status")
        port_profile_status.text = kwargs.pop('port_profile_status')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_input_request_type_getnext_request_last_received_port_profile_info_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        input = ET.SubElement(get_port_profile_status, "input")
        request_type = ET.SubElement(input, "request-type")
        getnext_request = ET.SubElement(request_type, "getnext-request")
        last_received_port_profile_info = ET.SubElement(getnext_request, "last-received-port-profile-info")
        profile_name = ET.SubElement(last_received_port_profile_info, "profile-name")
        profile_name.text = kwargs.pop('profile_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_input_request_type_getnext_request_last_received_port_profile_info_profile_mac(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        input = ET.SubElement(get_port_profile_status, "input")
        request_type = ET.SubElement(input, "request-type")
        getnext_request = ET.SubElement(request_type, "getnext-request")
        last_received_port_profile_info = ET.SubElement(getnext_request, "last-received-port-profile-info")
        profile_mac = ET.SubElement(last_received_port_profile_info, "profile-mac")
        profile_mac.text = kwargs.pop('profile_mac')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name = ET.SubElement(port_profile, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_ppid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        ppid = ET.SubElement(port_profile, "ppid")
        ppid.text = kwargs.pop('ppid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_is_active(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        is_active = ET.SubElement(port_profile, "is-active")
        is_active.text = kwargs.pop('is_active')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_mac_association_mac(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        mac_association = ET.SubElement(port_profile, "mac-association")
        mac = ET.SubElement(mac_association, "mac")
        mac.text = kwargs.pop('mac')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_mac_association_applied_interface_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        mac_association = ET.SubElement(port_profile, "mac-association")
        mac_key = ET.SubElement(mac_association, "mac")
        mac_key.text = kwargs.pop('mac')
        applied_interface = ET.SubElement(mac_association, "applied-interface")
        interface_type = ET.SubElement(applied_interface, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_mac_association_applied_interface_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        mac_association = ET.SubElement(port_profile, "mac-association")
        mac_key = ET.SubElement(mac_association, "mac")
        mac_key.text = kwargs.pop('mac')
        applied_interface = ET.SubElement(mac_association, "applied-interface")
        interface_name = ET.SubElement(applied_interface, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_has_more(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        has_more = ET.SubElement(port_profile, "has-more")
        has_more.text = kwargs.pop('has_more')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        input = ET.SubElement(get_port_profile_for_intf, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_input_request_type_get_request_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        input = ET.SubElement(get_port_profile_for_intf, "input")
        request_type = ET.SubElement(input, "request-type")
        get_request = ET.SubElement(request_type, "get-request")
        interface_type = ET.SubElement(get_request, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_input_request_type_get_request_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        input = ET.SubElement(get_port_profile_for_intf, "input")
        request_type = ET.SubElement(input, "request-type")
        get_request = ET.SubElement(request_type, "get-request")
        interface_name = ET.SubElement(get_request, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_input_request_type_getnext_request_last_received_interface_info_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        input = ET.SubElement(get_port_profile_for_intf, "input")
        request_type = ET.SubElement(input, "request-type")
        getnext_request = ET.SubElement(request_type, "getnext-request")
        last_received_interface_info = ET.SubElement(getnext_request, "last-received-interface-info")
        interface_type = ET.SubElement(last_received_interface_info, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_input_request_type_getnext_request_last_received_interface_info_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        input = ET.SubElement(get_port_profile_for_intf, "input")
        request_type = ET.SubElement(input, "request-type")
        getnext_request = ET.SubElement(request_type, "getnext-request")
        last_received_interface_info = ET.SubElement(getnext_request, "last-received-interface-info")
        interface_name = ET.SubElement(last_received_interface_info, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_output_interface_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        output = ET.SubElement(get_port_profile_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_type = ET.SubElement(interface, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_output_interface_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        output = ET.SubElement(get_port_profile_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_name = ET.SubElement(interface, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_output_interface_port_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        output = ET.SubElement(get_port_profile_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        port_profile = ET.SubElement(interface, "port-profile")
        name = ET.SubElement(port_profile, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_for_intf_output_has_more(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_for_intf = ET.Element("get_port_profile_for_intf")
        config = get_port_profile_for_intf
        output = ET.SubElement(get_port_profile_for_intf, "output")
        has_more = ET.SubElement(output, "has-more")
        has_more.text = kwargs.pop('has_more')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        input = ET.SubElement(get_port_profile_status, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_input_port_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        input = ET.SubElement(get_port_profile_status, "input")
        port_profile_name = ET.SubElement(input, "port-profile-name")
        port_profile_name.text = kwargs.pop('port_profile_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_input_port_profile_status(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        input = ET.SubElement(get_port_profile_status, "input")
        port_profile_status = ET.SubElement(input, "port-profile-status")
        port_profile_status.text = kwargs.pop('port_profile_status')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_input_request_type_getnext_request_last_received_port_profile_info_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        input = ET.SubElement(get_port_profile_status, "input")
        request_type = ET.SubElement(input, "request-type")
        getnext_request = ET.SubElement(request_type, "getnext-request")
        last_received_port_profile_info = ET.SubElement(getnext_request, "last-received-port-profile-info")
        profile_name = ET.SubElement(last_received_port_profile_info, "profile-name")
        profile_name.text = kwargs.pop('profile_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_input_request_type_getnext_request_last_received_port_profile_info_profile_mac(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        input = ET.SubElement(get_port_profile_status, "input")
        request_type = ET.SubElement(input, "request-type")
        getnext_request = ET.SubElement(request_type, "getnext-request")
        last_received_port_profile_info = ET.SubElement(getnext_request, "last-received-port-profile-info")
        profile_mac = ET.SubElement(last_received_port_profile_info, "profile-mac")
        profile_mac.text = kwargs.pop('profile_mac')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name = ET.SubElement(port_profile, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_ppid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        ppid = ET.SubElement(port_profile, "ppid")
        ppid.text = kwargs.pop('ppid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_is_active(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        is_active = ET.SubElement(port_profile, "is-active")
        is_active.text = kwargs.pop('is_active')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_mac_association_mac(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        mac_association = ET.SubElement(port_profile, "mac-association")
        mac = ET.SubElement(mac_association, "mac")
        mac.text = kwargs.pop('mac')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_mac_association_applied_interface_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        mac_association = ET.SubElement(port_profile, "mac-association")
        mac_key = ET.SubElement(mac_association, "mac")
        mac_key.text = kwargs.pop('mac')
        applied_interface = ET.SubElement(mac_association, "applied-interface")
        interface_type = ET.SubElement(applied_interface, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_mac_association_applied_interface_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        mac_association = ET.SubElement(port_profile, "mac-association")
        mac_key = ET.SubElement(mac_association, "mac")
        mac_key.text = kwargs.pop('mac')
        applied_interface = ET.SubElement(mac_association, "applied-interface")
        interface_name = ET.SubElement(applied_interface, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_profile_status_output_port_profile_has_more(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_profile_status = ET.Element("get_port_profile_status")
        config = get_port_profile_status
        output = ET.SubElement(get_port_profile_status, "output")
        port_profile = ET.SubElement(output, "port-profile")
        name_key = ET.SubElement(port_profile, "name")
        name_key.text = kwargs.pop('name')
        has_more = ET.SubElement(port_profile, "has-more")
        has_more.text = kwargs.pop('has_more')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_intf_loopback(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def hide_intf_loopback_holder_interface_loopback_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id = ET.SubElement(loopback, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_vrf_forwarding(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        vrf = ET.SubElement(loopback, "vrf")
        forwarding = ET.SubElement(vrf, "forwarding")
        forwarding.text = kwargs.pop('forwarding')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_intf_loopback_shutdown(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        intf_loopback = ET.SubElement(loopback, "intf-loopback")
        shutdown = ET.SubElement(intf_loopback, "shutdown")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ip_ip_config_address_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ip = ET.SubElement(loopback, "ip", xmlns="urn:brocade.com:mgmt:brocade-ip-config")
        ip_config = ET.SubElement(ip, "ip-config")
        address = ET.SubElement(ip_config, "address")
        address = ET.SubElement(address, "address")
        address.text = kwargs.pop('address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_use_link_local_only(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        use_link_local_only = ET.SubElement(address, "use-link-local-only")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_link_local_config_link_local_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        link_local_config = ET.SubElement(address, "link-local-config")
        link_local_address = ET.SubElement(link_local_config, "link-local-address")
        link_local_address.text = kwargs.pop('link_local_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_link_local_config_link_local(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        link_local_config = ET.SubElement(address, "link-local-config")
        link_local = ET.SubElement(link_local_config, "link-local")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_ipv6_address_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        ipv6_address = ET.SubElement(address, "ipv6-address")
        address = ET.SubElement(ipv6_address, "address")
        address.text = kwargs.pop('address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_ipv6_address_eui64(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        ipv6_address = ET.SubElement(address, "ipv6-address")
        address_key = ET.SubElement(ipv6_address, "address")
        address_key.text = kwargs.pop('address')
        eui64 = ET.SubElement(ipv6_address, "eui64")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_ipv6_address_anycast(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        ipv6_address = ET.SubElement(address, "ipv6-address")
        address_key = ET.SubElement(ipv6_address, "address")
        address_key.text = kwargs.pop('address')
        anycast = ET.SubElement(ipv6_address, "anycast")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id = ET.SubElement(loopback, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_vrf_forwarding(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        vrf = ET.SubElement(loopback, "vrf")
        forwarding = ET.SubElement(vrf, "forwarding")
        forwarding.text = kwargs.pop('forwarding')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_intf_loopback_shutdown(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        intf_loopback = ET.SubElement(loopback, "intf-loopback")
        shutdown = ET.SubElement(intf_loopback, "shutdown")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ip_ip_config_address_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ip = ET.SubElement(loopback, "ip", xmlns="urn:brocade.com:mgmt:brocade-ip-config")
        ip_config = ET.SubElement(ip, "ip-config")
        address = ET.SubElement(ip_config, "address")
        address = ET.SubElement(address, "address")
        address.text = kwargs.pop('address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_use_link_local_only(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        use_link_local_only = ET.SubElement(address, "use-link-local-only")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_link_local_config_link_local_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        link_local_config = ET.SubElement(address, "link-local-config")
        link_local_address = ET.SubElement(link_local_config, "link-local-address")
        link_local_address.text = kwargs.pop('link_local_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_link_local_config_link_local(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        link_local_config = ET.SubElement(address, "link-local-config")
        link_local = ET.SubElement(link_local_config, "link-local")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_ipv6_address_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        ipv6_address = ET.SubElement(address, "ipv6-address")
        address = ET.SubElement(ipv6_address, "address")
        address.text = kwargs.pop('address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_ipv6_address_eui64(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        ipv6_address = ET.SubElement(address, "ipv6-address")
        address_key = ET.SubElement(ipv6_address, "address")
        address_key.text = kwargs.pop('address')
        eui64 = ET.SubElement(ipv6_address, "eui64")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_intf_loopback_holder_interface_loopback_ipv6_ipv6_config_address_ipv6_address_anycast(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_intf_loopback_holder = ET.SubElement(config, "hide-intf-loopback-holder", xmlns="urn:brocade.com:mgmt:brocade-intf-loopback")
        interface = ET.SubElement(hide_intf_loopback_holder, "interface")
        loopback = ET.SubElement(interface, "loopback")
        id_key = ET.SubElement(loopback, "id")
        id_key.text = kwargs.pop('id')
        ipv6 = ET.SubElement(loopback, "ipv6", xmlns="urn:brocade.com:mgmt:brocade-ipv6-config")
        ipv6_config = ET.SubElement(ipv6, "ipv6-config")
        address = ET.SubElement(ipv6_config, "address")
        ipv6_address = ET.SubElement(address, "ipv6-address")
        address_key = ET.SubElement(ipv6_address, "address")
        address_key.text = kwargs.pop('address')
        anycast = ET.SubElement(ipv6_address, "anycast")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_isns(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def isns_isns_vrf_isns_vrf_instance(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance.text = kwargs.pop('isns_vrf_instance')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_isns_ipaddress_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        isns_ipaddress = ET.SubElement(isns_vrf, "isns-ipaddress")
        ip = ET.SubElement(isns_ipaddress, "ip")
        ip.text = kwargs.pop('ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_isns_ipaddress_loopback(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        isns_ipaddress = ET.SubElement(isns_vrf, "isns-ipaddress")
        loopback = ET.SubElement(isns_ipaddress, "loopback")
        loopback.text = kwargs.pop('loopback')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_esi_timeout(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        esi_timeout = ET.SubElement(isns_vrf, "esi-timeout")
        esi_timeout.text = kwargs.pop('esi_timeout')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_isns_discovery_domain_isns_discovery_domain_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        isns_discovery_domain = ET.SubElement(isns_vrf, "isns-discovery-domain")
        isns_discovery_domain_name = ET.SubElement(isns_discovery_domain, "isns-discovery-domain-name")
        isns_discovery_domain_name.text = kwargs.pop('isns_discovery_domain_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_isns_discovery_domain_set_isns_discovery_domain_set_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        isns_discovery_domain_set = ET.SubElement(isns_vrf, "isns-discovery-domain-set")
        isns_discovery_domain_set_name = ET.SubElement(isns_discovery_domain_set, "isns-discovery-domain-set-name")
        isns_discovery_domain_set_name.text = kwargs.pop('isns_discovery_domain_set_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_isns_discovery_domain_set_isns_discovery_domain_set_enable(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        isns_discovery_domain_set = ET.SubElement(isns_vrf, "isns-discovery-domain-set")
        isns_discovery_domain_set_name_key = ET.SubElement(isns_discovery_domain_set, "isns-discovery-domain-set-name")
        isns_discovery_domain_set_name_key.text = kwargs.pop('isns_discovery_domain_set_name')
        isns_discovery_domain_set_enable = ET.SubElement(isns_discovery_domain_set, "isns-discovery-domain-set-enable")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_isns_vrf_instance(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance.text = kwargs.pop('isns_vrf_instance')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_isns_ipaddress_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        isns_ipaddress = ET.SubElement(isns_vrf, "isns-ipaddress")
        ip = ET.SubElement(isns_ipaddress, "ip")
        ip.text = kwargs.pop('ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_isns_ipaddress_loopback(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        isns_ipaddress = ET.SubElement(isns_vrf, "isns-ipaddress")
        loopback = ET.SubElement(isns_ipaddress, "loopback")
        loopback.text = kwargs.pop('loopback')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_esi_timeout(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        esi_timeout = ET.SubElement(isns_vrf, "esi-timeout")
        esi_timeout.text = kwargs.pop('esi_timeout')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_isns_discovery_domain_isns_discovery_domain_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        isns_discovery_domain = ET.SubElement(isns_vrf, "isns-discovery-domain")
        isns_discovery_domain_name = ET.SubElement(isns_discovery_domain, "isns-discovery-domain-name")
        isns_discovery_domain_name.text = kwargs.pop('isns_discovery_domain_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_isns_discovery_domain_set_isns_discovery_domain_set_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        isns_discovery_domain_set = ET.SubElement(isns_vrf, "isns-discovery-domain-set")
        isns_discovery_domain_set_name = ET.SubElement(isns_discovery_domain_set, "isns-discovery-domain-set-name")
        isns_discovery_domain_set_name.text = kwargs.pop('isns_discovery_domain_set_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def isns_isns_vrf_isns_discovery_domain_set_isns_discovery_domain_set_enable(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        isns = ET.SubElement(config, "isns", xmlns="urn:brocade.com:mgmt:brocade-isns")
        isns_vrf = ET.SubElement(isns, "isns-vrf")
        isns_vrf_instance_key = ET.SubElement(isns_vrf, "isns-vrf-instance")
        isns_vrf_instance_key.text = kwargs.pop('isns_vrf_instance')
        isns_discovery_domain_set = ET.SubElement(isns_vrf, "isns-discovery-domain-set")
        isns_discovery_domain_set_name_key = ET.SubElement(isns_discovery_domain_set, "isns-discovery-domain-set-name")
        isns_discovery_domain_set_name_key.text = kwargs.pop('isns_discovery_domain_set_name')
        isns_discovery_domain_set_enable = ET.SubElement(isns_discovery_domain_set, "isns-discovery-domain-set-enable")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        